@@ -9,6 +9,9 @@ def preflight(*args):
         "Access-Control-Max-Age": "3600"
     }
 
+def cors(response, code):
+    return response, code, { "Access-Control-Allow-Origin": "*"}
+
 class Endpoint:
     http_verbs = ["get", "head", "post", "put", "delete", "connect", "options",
                   "trace", "patch"]
@@ -30,4 +33,4 @@ class Endpoint:
         if method not in methods:
             return not_allowed
 
-        return getattr(cls, method)
+        return cors(*getattr(cls, method))
